#include <glib.h>
#include <network_api.h>
#include <gconf/gconf-client.h>

#define CONNECTIONS_DIR "/system/osso/connectivity/IAP"

gchar * ver = ICD_NW_MODULE_VERSION;

static void
nw_start_search_fn (const gchar *network_type,
                           guint search_scope,
                           icd_nw_search_cb_fn search_cb,
                           const gpointer search_cb_token,
                           gpointer *private) {
	GConfClient* gconf;
	GSList * dirs, *d;

	gconf = gconf_client_get_default ();

	dirs = gconf_client_all_dirs(gconf, CONNECTIONS_DIR, NULL);
	if (dirs && g_slist_length (dirs)>0) {
		d = dirs;
		while(d) {
			gchar *n, *id, key[256], *t, *m;
			n=d->data;

			id = g_path_get_basename(n);
			g_snprintf(key, 255, "%s/type", n);
			t=gconf_client_get_string(gconf, key, NULL);
			if ( ! strcmp("DUMMY", t)) {
				g_snprintf(key, 255, "%s/name", n);
				m=gconf_client_get_string(gconf, key, NULL);
				if(m) search_cb(ICD_NW_SEARCH_CONTINUE, m, 
						"DUMMY", ICD_NW_ATTR_AUTOCONNECT, id, ICD_NW_LEVEL_10, "aaaa", 0, search_cb_token);
				g_free(m);
			}
			g_free(id);
			g_free(t);
			d=d->next;
		}
		g_slist_foreach (dirs, (GFunc) g_free, NULL);
//		g_free_slist(dirs);
	}
	g_object_unref(gconf);
	search_cb(ICD_NW_SEARCH_COMPLETE, "", "DUMMY", ICD_NW_ATTR_AUTOCONNECT, "", 0, "", 0, search_cb_token);
}

gboolean icd_nw_init (struct icd_nw_api *network_api, 
		icd_nw_watch_pid_fn watch_fn, 
		gpointer watch_fn_token, 
		icd_nw_close_fn close_fn, 
		icd_nw_status_change_fn status_change_fn, 
		icd_nw_renew_fn renew_fn) {
	
	network_api->version = ver;
	network_api->private = (void *)0x1234abcd;
	network_api->ip_down = NULL;
	network_api->ip_up = NULL;
	network_api->ip_addr_info = NULL;
	network_api->ip_stats = NULL;
	network_api->link_pre_down = NULL;
	network_api->link_post_up = NULL;
	network_api->link_post_stats = NULL;
	network_api->link_down = NULL;
	network_api->link_up = NULL;
	network_api->link_stats = NULL;
	network_api->search_lifetime = 86400*365*10;
	network_api->search_interval = 86400*365*8;
	network_api->start_search = nw_start_search_fn;
	network_api->stop_search = NULL;
	network_api->child_exit = NULL;
	network_api->network_destruct = NULL;
	network_api->ip_renew = NULL;
	network_api->link_post_renew = NULL;
	network_api->link_renew = NULL;

	return TRUE;
}
